@@ -2,7 +2,7 @@
 --  Copyright (C) 2004-2011 by CERN/IT/GD/CT
 --  All rights reserved
 --
---       @(#)$RCSfile: dpm_mysql_tbl.sql,v $ $Revision: 7068 $ $Date: 2012-08-30 12:04:36 +0200 (Thu, 30 Aug 2012) $ CERN IT-GD/CT Jean-Philippe Baud
+--       @(#)$RCSfile: dpm_mysql_tbl.sql,v $ $Revision: 12857 $ $Date: 2016-09-12 13:35:19 +0200 (Mon, 12 Sep 2016) $ CERN IT-GD/CT Jean-Philippe Baud
  
 --     Create Disk Pool Manager MySQL tables.
 
@@ -152,7 +152,8 @@ CREATE TABLE dpm_space_reserv (
        poolname VARCHAR(15) BINARY,
        assign_time INTEGER,
        expire_time INTEGER,
-       groups VARCHAR(255) BINARY)
+       groups VARCHAR(255) BINARY,
+       path VARCHAR(255) BINARY)
 	ENGINE = InnoDB;
 
 CREATE TABLE dpm_unique_id (
@@ -198,4 +199,4 @@ CREATE TABLE schema_version_dpm (
 ) ENGINE=INNODB;
 
 INSERT INTO schema_version_dpm (major, minor, patch)
-  VALUES (3, 4, 0);
+  VALUES (3, 5, 0);
