@@ -18,9 +18,11 @@
 #  v1.0.0 initial release
 #  v1.0.2 removed site debug printouts that were screwing up the output
 #  v1.0.3 avoid summing the size fields for directories. Fixes EGI doublecounting
+#  v1.0.4 marks the report as regarding the past period, not the next one; parse
+#         the DPM group names into VO and role
 #
 
-__version__ = "1.0.3"
+__version__ = "1.0.4"
 __author__  = "Fabrizio Furano"
 
 
@@ -50,7 +52,6 @@ import datetime
 
 
 
-
 # yum install MySQL-python python-lxml python-uuid
 
 def addrecord(xmlroot, hostname, group, user, site, filecount, resourcecapacityused, logicalcapacityused, validduration, recordid = None):
@@ -71,8 +72,32 @@ def addrecord(xmlroot, hostname, group, user, site, filecount, resourcecapacityu
   subjid = etree.SubElement(rec, SR+'SubjectIdentity')
 
   if group:
+    grouproles = group.split('/')
+
+    # If the last token is Role=... then we fetch the role and add it to the record
+    tmprl = grouproles[-1]
+    if tmprl.find('Role=') != -1:
+      splitroles = tmprl.split('=')
+      if (len(splitroles) > 1):
+        role = splitroles[1]
+        grp = etree.SubElement(subjid, SR+"GroupAttribute" )
+        grp.set( SR+"attributeType", "role" )
+        grp.text = role
+      # Now drop this last token, what remains is the vo identifier
+      grouproles.pop()
+
+
+    # The voname is the first token
+    voname = grouproles.pop(0)
     grp = etree.SubElement(subjid, SR+"Group")
-    grp.text = group
+    grp.text = voname
+
+    # If there are other tokens, they are a subgroup
+    if len(grouproles) > 0:
+      subgrp = '/'.join(grouproles)
+      grp = etree.SubElement(subjid, SR+"GroupAttribute" )
+      grp.set( SR+"attributeType", "subgroup" )
+      grp.text = subgrp
 
   if user:
     usr = etree.SubElement(subjid, SR+"User")
@@ -86,11 +111,11 @@ def addrecord(xmlroot, hostname, group, user, site, filecount, resourcecapacityu
   e.text = "disk"
 
   if validduration:
-    e = etree.SubElement(rec, SR+"EndTime")
-    d = datetime.datetime.utcnow() + datetime.timedelta(seconds=validduration)
+    e = etree.SubElement(rec, SR+"StartTime")
+    d = datetime.datetime.utcnow() - datetime.timedelta(seconds=validduration)
     e.text = d.strftime("%Y-%m-%dT%H:%M:%SZ")
 
-  e = etree.SubElement(rec, SR+"StartTime")
+  e = etree.SubElement(rec, SR+"EndTime")
   e.text = datetime.datetime.utcnow().strftime("%Y-%m-%dT%H:%M:%SZ")
 
 
@@ -206,7 +231,7 @@ parser.add_option('--nsconfig', dest='nsconfig', default=None, help="Path to the
 parser.add_option('--dbhost', dest='dbhost', default=None, help="Database host, if no NSCONFIG given")
 parser.add_option('--dbuser', dest='dbuser', default=None, help="Database user, if no NSCONFIG given")
 parser.add_option('--dbpwd', dest='dbpwd', default=None, help="Database password, if no NSCONFIG given")
-parser.add_option('--validduration', dest='validduration', default=2592000, help="Valid duration of this record, in seconds (default: 1 month)")
+parser.add_option('--validduration', dest='validduration', default=86400, help="Valid duration of this record, in seconds (default: 1 day)")
 options, args = parser.parse_args()
 
 record_id = options.recordid
